git.lucas.co / cce-compositor
Wayland compositor (wlroots)
git clone https://git.lucas.co/cce-compositor.git

commita6524cc6088e68c69a621bdf12a570314d1da02e
parent4023f96a09
authorLeon Henrik Plickat <[email protected]>
date2020-07-08 02:39
cursor: close view on middleclick when pointer_modifier is active

 river/Cursor.zig | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/river/Cursor.zig b/river/Cursor.zig
index e6add16..7b72729 100644
--- a/river/Cursor.zig
+++ b/river/Cursor.zig
@@ -246,12 +246,12 @@ fn handleButton(listener: ?*c.wl_listener, data: ?*c_void) callconv(.C) void {
 
                 if (event.state == .WLR_BUTTON_PRESSED) {
                     // If the button is pressed and the pointer modifier is
                     // active, enter cursor mode and return.
                     if (self.seat.pointer_modifier) {
                         switch (event.button) {
                             c.BTN_LEFT => enterCursorMode(self, event, view, CursorMode.Move),
+                            c.BTN_MIDDLE => view.close(),
                             c.BTN_RIGHT => {}, // TODO Resize
-                            c.BTN_MIDDLE => {}, // TODO Some useful operation, maybe kill
 
                             // TODO Some mice have additional buttons. These
                             // could also be bound to some useful action.
@@ -246,12 +246,12 @@ fn handleButton(listener: ?*c.wl_listener, data: ?*c_void) callconv(.C) void {
                 if (event.state == .WLR_BUTTON_PRESSED) {
                     // If the button is pressed and the pointer modifier is
-                    // active, enter cursor mode and return.
+                    // active, enter cursor mode or close view and return.
                     if (self.seat.pointer_modifier) {
                         switch (event.button) {